@@ -519,42 +519,6 @@ get_disk_size (char * devname) {
 	return -1;
 }
 
-int
-do_tur(char *devt)
-{
-	unsigned char turCmdBlk[TUR_CMD_LEN] = { 0x00, 0, 0, 0, 0, 0 };
-	struct sg_io_hdr io_hdr;
-	unsigned char sense_buffer[32];
-	int fd;
-
-	fd = opennode(devt, O_RDONLY);
-	
-	if (fd < 0)
-		return 0;
-
-	memset(&io_hdr, 0, sizeof (struct sg_io_hdr));
-	io_hdr.interface_id = 'S';
-	io_hdr.cmd_len = sizeof (turCmdBlk);
-	io_hdr.mx_sb_len = sizeof (sense_buffer);
-	io_hdr.dxfer_direction = SG_DXFER_NONE;
-	io_hdr.cmdp = turCmdBlk;
-	io_hdr.sbp = sense_buffer;
-	io_hdr.timeout = 20000;
-	io_hdr.pack_id = 0;
-
-	if (ioctl(fd, SG_IO, &io_hdr) < 0) {
-		closenode(devt, fd);
-		return 0;
-	}
-
-	closenode(devt, fd);
-	
-	if (io_hdr.info & SG_INFO_OK_MASK)
-		return 0;
-
-	return 1;
-}
-
 /*
  * get EVPD page 0x83 off 8
  * tested ok with StorageWorks
