@@ -1,8 +1,9 @@
+#include <syslog.h>
+#include <checkers.h>
+
 #include "parser.h"
 #include "memory.h"
 #include "hwtable.h"
-#include "log.h"
-#include "libcheckers/checkers.h"
 
 /*
  * helper function to draw a list of callout binaries found in the config file
@@ -31,7 +32,7 @@ push_callout(char * callout)
 	for (i = 0; i < VECTOR_SIZE(binvec); i++) {
 		bin = VECTOR_SLOT(binvec, i);
 
-		if (memcmp (bin, callout, p - callout) == 0)
+		if (memcmp(bin, callout, p - callout) == 0)
 			return;
 	}
 	/*
@@ -39,7 +40,7 @@ push_callout(char * callout)
 	 */
 	bin = MALLOC(p - callout);
 	strncpy(bin, callout, p - callout);
-	LOG(3, "add %s to binvec", bin);
+	syslog(LOG_DEBUG, "add %s to binvec", bin);
 
 	vector_alloc_slot(binvec);
 	vector_set_slot(binvec, bin);
@@ -58,7 +59,10 @@ multipath_tool_handler(vector strvec)
 static void
 polling_interval_handler(vector strvec)
 {
-	checkint = atoi(VECTOR_SLOT(strvec, 1));
+	char * buff;
+
+	buff = VECTOR_SLOT(strvec, 1);
+	checkint = atoi(buff);
 }
 
 static void
